<?php


	Class Extension_PHPIDS_Connector extends Extension {

		public function about() {
			return array(
				'name' => 'PHPIDS Connector for phpids 0.7',
				'version' => '0.1',
				'release-date' => '2012-01-24',
				'author' => array( 

					array(
						'name' => 'Janosch Rux',
						'website' => '',
						'email' => 'janosch.rux@web.de'
					),
					array(
                                        	'name' => 'PHPIDS Team',
                                        	'website' => 'https://phpids.org/',
                                        	'email' => ''
					)
				  ),

				'description' => 'Checks POST, GET and Cookies Fields for XSS, SQL Injection, header injection, directory traversal, RFE/LFI, DoS and LDAP attacks.'
			);
		}

		public function install() {
			require("lib/utils.php");
                        $ini = parse_ini_file(dirname(__FILE__)."/connector.ini");
			$ini['symphony_url'] = URL;
			write_ini_file(dirname(__FILE__)."/connector.ini", $ini);

		}


                public function getSubscribedDelegates(){
                        return
                                array( array (
                                       		'page' => '/system/preferences/',
                                        	'delegate' => 'AddCustomPreferenceFieldsets',
                                	        'callback' => 'appendPreferences'
		                        ),
					array (
						'page' => '/system/preferences/',
						'delegate' => 'Save',
						'callback' => 'savePreferences'
					)
				      );
                }

                public function appendPreferences($context) {

			//load ini
			$ini = parse_ini_file(dirname(__FILE__)."/connector.ini");

                        // Create preference group
                        $group = new XMLElement('fieldset');
                        $group->setAttribute('class', 'settings');
                        $group->appendChild(new XMLElement('legend', __('PHPIDS Configuration')));

			//Append prepend notice
                        $label = Widget::Label();
                        $phpids_loc = dirname(__FILE__)."/invoke-ids.php";
                        $label->setValue('<h3>To enable phpids add the following to the .htaccess:</h3><br /><code>php_value auto_prepend_file '.$phpids_loc.'</code>');
                        $group->appendChild($label);


                        //Append active setting
                        $label = Widget::Label();
			$input = Widget::Input('phpids_connector[active]', 'true', 'checkbox');
                        if($ini['active'])
				$input->setAttribute('checked', 'checked');
                        $label->setValue($input->generate() . ' ' . __('Enable PHPIDS'));
                        $group->appendChild($label);

			$group->appendChild(new XMLElement('p', __('Please note that the <code>auto_prepend_file</code> directive has to be set anyway'), array('class' => 'help')));


			//append File Loggin active
			$label = Widget::Label();
			$input = Widget::Input('phpids_connector[filelogging]', 'true', 'checkbox');
			if($ini['filelogging'])
				$input->setAttribute('checked', 'checked');
			$label->setValue($input->generate() . ' ' . __('Enable Filelogging'));
			$group->appendChild($label);

			//info to filelogging
			$group->appendChild(new XMLElement('p', __('Logs to tmp/phpids_log.txt in the PHPIDS Folder'), array('class' => 'help')));


                        $label = Widget::Label();
                        $label->setValue("<h3> Select an Incident Response Action</h3>");
                        $group->appendChild($label);


                        //append redirect option
                        $label = Widget::Label();
                        $input = Widget::Input('phpids_connector[action]', 'redirect', 'radio');
                        if($ini['action'] == "redirect")
                                $input->setAttribute('checked', 'checked');
                        $label->setValue($input->generate() . ' ' . __('Enable Redirect'));
                        $group->appendChild($label);

                        //info to redirect
                        $group->appendChild(new XMLElement('p', __('The incident will be logged (if enabled), all sent data removed and the page, standing below, shown. '), array('class' => 'help')));

                        //Append redirect URL
                        $label = Widget::Label();
                        $input = Widget::Input('phpids_connector[redirect_url]', $ini['redirect_url'], 'text');
                        $label->setValue($input->generate());
                        $group->appendChild($label);


                        //Append lol option
                        $label = Widget::Label();
                        $input = Widget::Input('phpids_connector[action]', 'rating', 'radio');
                        if($ini['action'] == "rating")
                                $input->setAttribute('checked', 'checked');
                        $label->setValue($input->generate() . ' ' . __('Terminate the Request and display a humorous notice with a simple attack rating.'));
                        $group->appendChild($label);


			//Append the logonly
			$label = Widget::Label();
                        $input = Widget::Input('phpids_connector[action]', 'logonly', 'radio');
                        if($ini['action'] == "logonly")
                                $input->setAttribute('checked', 'checked');
                        $label->setValue($input->generate() . ' ' . __('Log Only. When enabled the session won\'t be terminate and no notice will be displayed. <b>NOT RECOMMENDED!</b>'));
                        $group->appendChild($label);

                        // Add everything to the page
                        $context['wrapper']->appendChild($group);
              }


		public function savePreferences($context) {
			require("lib/utils.php");
			$ini = parse_ini_file(dirname(__FILE__)."/connector.ini");

                        if(isset($_POST['phpids_connector'])) {
				$settings = $_POST['phpids_connector'];

				//Acivate PHPIDS
				if ( $settings['active'] == "true")
					$ini['active'] =  1;
				else
					$ini['active'] = 0;

				if( $settings['filelogging'] == "true")
					$ini['filelogging'] = 1;
				else
					$ini['filelogging'] = 0;


				if ($settings['action'] ==  "logonly" || $settings['action'] ==  "redirect" || $settings['action'] ==  "rating")
                                	$ini['action'] = $settings['action'];

				$ini['redirect_url'] = $settings['redirect_url'];

				write_ini_file(dirname(__FILE__)."/connector.ini", $ini);
			}
		}

	}

?>
